@@ -10,7 +10,7 @@
 #
 # All other ideas have to be set in Manager/Build/Attributes.pm !
 
-# DON'T FORGET TO RUN "make json" AFTER EACH CHANGE
+# DON'T FORGET TO RUN 'make json' AFTER EACH CHANGE
 
 package Lemonldap::NG::Manager::Build::CTrees;
 
@@ -27,11 +27,11 @@ sub cTrees {
                 help  => 'configvhost.html#options',
                 form  => 'simpleInputContainer',
                 nodes => [
-                    'vhostPort',          'vhostHttps',
-                    'vhostMaintenance',   'vhostAliases',
-                    'vhostAccessToTrace', 'vhostType',
-                    'vhostAuthnLevel',    'vhostDevOpsRulesUrl',
-                    'vhostServiceTokenTTL'
+                    'vhostPort',            'vhostHttps',
+                    'vhostMaintenance',     'vhostAliases',
+                    'vhostAccessToTrace',   'vhostAuthnLevel',
+                    'vhostType',            'vhostDevOpsRulesUrl',
+                    'vhostServiceTokenTTL', 'vhostComment'
                 ],
             },
         ],
@@ -40,41 +40,41 @@ sub cTrees {
             'samlIDPMetaDataExportedAttributes',
 
             {
-                title => "samlIDPMetaDataOptionsSession",
+                title => 'samlIDPMetaDataOptionsSession',
                 form  => 'simpleInputContainer',
                 nodes => [
-                    "samlIDPMetaDataOptionsAdaptSessionUtime",
-                    "samlIDPMetaDataOptionsForceUTF8",
-                    "samlIDPMetaDataOptionsStoreSAMLToken",
-                    "samlIDPMetaDataOptionsUserAttribute"
+                    'samlIDPMetaDataOptionsAdaptSessionUtime',
+                    'samlIDPMetaDataOptionsForceUTF8',
+                    'samlIDPMetaDataOptionsStoreSAMLToken',
+                    'samlIDPMetaDataOptionsUserAttribute'
                 ]
             },
             {
-                title => "samlIDPMetaDataOptionsSignature",
+                title => 'samlIDPMetaDataOptionsSignature',
                 form  => 'simpleInputContainer',
                 nodes => [
-                    "samlIDPMetaDataOptionsSignatureMethod",
-                    "samlIDPMetaDataOptionsSignSSOMessage",
-                    "samlIDPMetaDataOptionsCheckSSOMessageSignature",
-                    "samlIDPMetaDataOptionsSignSLOMessage",
-                    "samlIDPMetaDataOptionsCheckSLOMessageSignature"
+                    'samlIDPMetaDataOptionsSignatureMethod',
+                    'samlIDPMetaDataOptionsSignSSOMessage',
+                    'samlIDPMetaDataOptionsCheckSSOMessageSignature',
+                    'samlIDPMetaDataOptionsSignSLOMessage',
+                    'samlIDPMetaDataOptionsCheckSLOMessageSignature'
                 ]
             },
             {
-                title => "samlIDPMetaDataOptionsBinding",
+                title => 'samlIDPMetaDataOptionsBinding',
                 form  => 'simpleInputContainer',
                 nodes => [
-                    "samlIDPMetaDataOptionsSSOBinding",
-                    "samlIDPMetaDataOptionsSLOBinding"
+                    'samlIDPMetaDataOptionsSSOBinding',
+                    'samlIDPMetaDataOptionsSLOBinding'
                 ]
             },
             {
-                title => "samlIDPMetaDataOptionsSecurity",
+                title => 'samlIDPMetaDataOptionsSecurity',
                 form  => 'simpleInputContainer',
                 nodes => [
-                    "samlIDPMetaDataOptionsEncryptionMode",
-                    "samlIDPMetaDataOptionsCheckTime",
-                    "samlIDPMetaDataOptionsCheckAudience"
+                    'samlIDPMetaDataOptionsEncryptionMode',
+                    'samlIDPMetaDataOptionsCheckTime',
+                    'samlIDPMetaDataOptionsCheckAudience'
                 ]
             },
             {
@@ -85,65 +85,81 @@ sub cTrees {
                     'samlIDPMetaDataOptionsNameIDFormat',
                     'samlIDPMetaDataOptionsForceAuthn',
                     'samlIDPMetaDataOptionsIsPassive',
-                    'samlIDPMetaDataOptionsAllowProxiedAuthn',
                     'samlIDPMetaDataOptionsAllowLoginFromIDP',
                     'samlIDPMetaDataOptionsRequestedAuthnContext',
                     'samlIDPMetaDataOptionsRelayStateURL',
+                    {
+                        title => 'samlIDPMetaDataOptionsFederation',
+                        form  => 'simpleInputContainer',
+                        nodes => [ 'samlIDPMetaDataOptionsFederationEntityID', ]
+                    },
+                    'samlIDPMetaDataOptionsComment'
                 ],
             },
             {
-                title => "samlIDPMetaDataOptionsDisplay",
+                title => 'samlIDPMetaDataOptionsDisplay',
                 form  => 'simpleInputContainer',
                 nodes => [
-                    "samlIDPMetaDataOptionsDisplayName",
-                    "samlIDPMetaDataOptionsIcon",
+                    'samlIDPMetaDataOptionsDisplayName',
+                    'samlIDPMetaDataOptionsIcon',
+                    'samlIDPMetaDataOptionsTooltip',
                     'samlIDPMetaDataOptionsResolutionRule',
-                    "samlIDPMetaDataOptionsSortNumber"
+                    'samlIDPMetaDataOptionsSortNumber'
                 ]
             }
         ],
         samlSPMetaDataNode => [
-            "samlSPMetaDataXML",
-            "samlSPMetaDataExportedAttributes",
+            'samlSPMetaDataXML',
+            'samlSPMetaDataExportedAttributes',
             {
-                title => "samlSPMetaDataOptions",
+                title => 'samlSPMetaDataOptions',
                 help  => 'idpsaml.html#options',
                 nodes => [ {
-                        title => "samlSPMetaDataOptionsAuthnResponse",
+                        title => 'samlSPMetaDataOptionsAuthnResponse',
                         form  => 'simpleInputContainer',
                         nodes => [
-                            "samlSPMetaDataOptionsNameIDFormat",
-                            "samlSPMetaDataOptionsNameIDSessionKey",
-                            "samlSPMetaDataOptionsOneTimeUse",
-                            "samlSPMetaDataOptionsSessionNotOnOrAfterTimeout",
-                            "samlSPMetaDataOptionsNotOnOrAfterTimeout",
-                            "samlSPMetaDataOptionsForceUTF8"
+                            'samlSPMetaDataOptionsNameIDFormat',
+                            'samlSPMetaDataOptionsNameIDSessionKey',
+                            'samlSPMetaDataOptionsOneTimeUse',
+                            'samlSPMetaDataOptionsSessionNotOnOrAfterTimeout',
+                            'samlSPMetaDataOptionsNotOnOrAfterTimeout',
+                            'samlSPMetaDataOptionsForceUTF8'
                         ]
                     },
                     {
-                        title => "samlSPMetaDataOptionsSignature",
+                        title => 'samlSPMetaDataOptionsSignature',
                         form  => 'simpleInputContainer',
                         nodes => [
-                            "samlSPMetaDataOptionsSignatureMethod",
-                            "samlSPMetaDataOptionsSignSSOMessage",
-                            "samlSPMetaDataOptionsCheckSSOMessageSignature",
-                            "samlSPMetaDataOptionsSignSLOMessage",
-                            "samlSPMetaDataOptionsCheckSLOMessageSignature",
+                            'samlSPMetaDataOptionsSignatureMethod',
+                            'samlSPMetaDataOptionsSignSSOMessage',
+                            'samlSPMetaDataOptionsCheckSSOMessageSignature',
+                            'samlSPMetaDataOptionsSignSLOMessage',
+                            'samlSPMetaDataOptionsCheckSLOMessageSignature',
                         ]
                     },
                     {
-                        title => "samlSPMetaDataOptionsSecurity",
+                        title => 'samlSPMetaDataOptionsSecurity',
                         form  => 'simpleInputContainer',
                         nodes => [
-                            "samlSPMetaDataOptionsEncryptionMode",
-                            "samlSPMetaDataOptionsEnableIDPInitiatedURL",
-                            "samlSPMetaDataOptionsAuthnLevel",
-                            "samlSPMetaDataOptionsRule",
+                            'samlSPMetaDataOptionsEncryptionMode',
+                            'samlSPMetaDataOptionsEnableIDPInitiatedURL',
+                            'samlSPMetaDataOptionsAuthnLevel',
+                            'samlSPMetaDataOptionsRule',
                         ]
-                    }
+                    },
+                    {
+                        title => 'samlSPMetaDataOptionsFederation',
+                        form  => 'simpleInputContainer',
+                        nodes => [
+                            'samlSPMetaDataOptionsFederationEntityID',
+                            'samlSPMetaDataOptionsFederationOptionalAttributes',
+                            'samlSPMetaDataOptionsFederationRequiredAttributes',
+                        ]
+                    },
+                    'samlSPMetaDataOptionsComment'
                 ]
             },
-            "samlSPMetaDataMacros",
+            'samlSPMetaDataMacros',
         ],
         oidcOPMetaDataNode => [
             'oidcOPMetaDataJSON',
@@ -178,6 +194,7 @@ sub cTrees {
                             'oidcOPMetaDataOptionsUseNonce'
                         ]
                     },
+                    'oidcOPMetaDataOptionsComment'
                 ]
             },
             {
@@ -186,30 +203,28 @@ sub cTrees {
                 nodes => [
                     'oidcOPMetaDataOptionsDisplayName',
                     'oidcOPMetaDataOptionsIcon',
+                    'oidcOPMetaDataOptionsTooltip',
                     'oidcOPMetaDataOptionsResolutionRule',
                     'oidcOPMetaDataOptionsSortNumber'
                 ]
             },
         ],
-        oidcRPMetaDataNode => [
+        oidcRPMetaDataNode => [ {
+                title => 'oidcRPMetaDataOptionsBasic',
+                help  => 'idpopenidconnect.html#basic-options',
+                form  => 'simpleInputContainer',
+                nodes => [
+                    'oidcRPMetaDataOptionsPublic',
+                    'oidcRPMetaDataOptionsClientID',
+                    'oidcRPMetaDataOptionsClientSecret',
+                    'oidcRPMetaDataOptionsRedirectUris'
+                ]
+            },
             'oidcRPMetaDataExportedVars',
-            'oidcRPMetaDataOptionsExtraClaims',
-            'oidcRPMetaDataScopeRules',
             {
                 title => 'oidcRPMetaDataOptions',
                 help  => 'idpopenidconnect.html#options',
-                nodes => [ 
-                {
-                        title => 'oidcRPMetaDataOptionsBasic',
-                        form  => 'simpleInputContainer',
-                        nodes => [
-                            'oidcRPMetaDataOptionsPublic',
-                            'oidcRPMetaDataOptionsClientID',
-                            'oidcRPMetaDataOptionsClientSecret',
-                            'oidcRPMetaDataOptionsRedirectUris',
-                        ]
-                    },
-                    {
+                nodes => [ {
                         title => 'oidcRPMetaDataOptionsAdvanced',
                         form  => 'simpleInputContainer',
                         nodes => [
@@ -222,6 +237,13 @@ sub cTrees {
                             'oidcRPMetaDataOptionsAdditionalAudiences',
                         ]
                     },
+                    {
+                        title => 'oidcRPMetaDataOptionsScopes',
+                        nodes => [
+                            'oidcRPMetaDataOptionsExtraClaims',
+                            'oidcRPMetaDataScopeRules',
+                        ]
+                    },
                     {
                         title => 'security',
                         form  => 'simpleInputContainer',
@@ -258,6 +280,7 @@ sub cTrees {
                             'oidcRPMetaDataOptionsPostLogoutRedirectUris',
                         ]
                     },
+                    'oidcRPMetaDataOptionsComment'
                 ]
             },
             'oidcRPMetaDataMacros',
@@ -280,6 +303,7 @@ sub cTrees {
                     'casSrvMetaDataOptionsUrl',
                     'casSrvMetaDataOptionsRenew',
                     'casSrvMetaDataOptionsGateway',
+                    'casSrvMetaDataOptionsComment'
                 ]
             },
             {
@@ -288,8 +312,9 @@ sub cTrees {
                 nodes => [
                     'casSrvMetaDataOptionsDisplayName',
                     'casSrvMetaDataOptionsIcon',
+                    'casSrvMetaDataOptionsTooltip',
                     'casSrvMetaDataOptionsResolutionRule',
-                    'casSrvMetaDataOptionsSortNumber',
+                    'casSrvMetaDataOptionsSortNumber'
                 ]
             },
         ],
@@ -302,7 +327,8 @@ sub cTrees {
                     'casAppMetaDataOptionsService',
                     'casAppMetaDataOptionsUserAttribute',
                     'casAppMetaDataOptionsAuthnLevel',
-                    'casAppMetaDataOptionsRule'
+                    'casAppMetaDataOptionsRule',
+                    'casAppMetaDataOptionsComment',
                 ]
             },
             'casAppMetaDataMacros',
